bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 22. Aventiure
___________________________________________________ #### Aventivre wie chriemhilt vnd ezele brvten #### in der stat ze wienne
###### 1336 | ### Si was ce zeizenmvre | vnz an den vierden tach ### div molte vff der straze | di wile ni gelach ### si ne stvebe alsam ez brvenne | allenthalben dan ### da ritten dvrch osteriche | des chvnich eceln man
###### 1337 | ### do was ovch dem chvenige | vil rehte nv geseit ### des im von den gedanchen | swunden siniv leit ### wi herlichen criemhilt | da chome dvrch div lant ### der kvenich begonde gahen | da er di wolgetanen vant
###### 1338 | ### von vil maniger sprache | sah man vffe den wegen ### vor eceln riten | manigen chvenen degen ### von cristen vnd von heiden | vil manige wite schar ### da si di vrowen fvnden | si chomen herliche dar
###### 1339 | ### von rivzen vnd von criechen | reit da vil manich man ### den poelan vnd den walachen | sach man swinde gan ### ir ross div vil gvten | da si mit creffte riten ### swaz si site heten | der wart vil wenich vermiten
###### 1340 | ### von dem lande ze chiewen | reit da vil manich degen ### vnt di wilden petsschenaere | da wart vil gepflegen ### mit dem bogen schiezen | cen vogeln di da flvgen ### di pfile si vil sere | zv den wenden vaste zvgen
###### 1341 | ### ein stat bi tvonowe | lit in osterlant ### div ist geheizen tvln | da wart ir bechant ### vil manich site vremede | den si e nie gesach ### si enpfiengen da genvge | den sit leit von ir gesach
###### 1342 | ### vor eceln dem chvenege | ein ingesinde reit ### vro vnd vil riche | hoefsh vnt gemeit ### wol vier vnd zweinzech fversten | tiwer vnd her ### daz si ir vrowen saehen | davon en gerten si niht mer
###### 1343 | ### der herzoge ramvnch | vzer walachen lant ### mit siben hvndert mannen | chom er fver si gerant ### sam vliegende vogele | sah man si varn ### do chom der fverste gybecke | mit vil herlichen scharn
###### 1344 | ### hornboge der snelle | wol mit tvsent man ### cherte von dem chvenege | gegen siner vrowen dan ### vil lvte wart geschallet | nach des landes siten ### von der hivnen magen | wart ovch da sere geritten
###### 1345 | ### do chom von tenemarchen | der chvene hawart ### vnt yrinch der vil snelle | vor valsche wol bewart ### vnt irnfrit von dveringen | ein waetlicher man ### si enpfiengen criemhilde | daz sis ere mvsen han
###### 1346 | ### mit zwelf hvndert mannen | di fvrtens in ir schar ### do chom der herre bloedelin | mit drin tvsent dar ### der eceln brvder | vzer hivnen lant ### der chom vil herliche | da er di chveneginne vant
###### 1347 | ### do chom der chvenich ecel | vnd ovch her dietrich ### mit allen sinen gesellen | da was vil lobelich ### manich ritter edele | biderbe vnd gvt ### des wart do vrovn criemhilde | vil wol gehoehet der mvt
###### 1348 | ### do sprach cer kveneginne | der herre rvedger ### vrowe ich wil enpfahen | hie den chvnich her ### swen ich ivch heize chvessen | daz sol sin getan ### ia ne mvgt ir niht geliche | gervzen alle eceln man
###### 1349 | ### do hvp man von dem moere | di chveneginne her ### ecel der vil riche | en beite do niht mer ### et stvnt von sinem rosse | mit manigem chvenem man ### man sah in vroliche | gegen criemhilde gan
###### 1350 | ### zwene fvrsten riche | als vns daz ist geseit ### bi der frvn gende | trvgn iriv chleit ### da ir der chvenich ecel | hin engegen gie ### da si den fvrsten edele | mit chvsse gvetelich enpfie
###### 1351 | ### vf rvchte si ir gebende | ir varwe wolgetan ### div lvht ir vz dem golde | da was vil manich man ### di iahen daz vrov helche | niht schoener chvnde sin ### dabi so stvnt vil nahen | des kveniges brvder bloedelin
###### 1352 | ### den hiez si chvessen rvedeger | der margrave rich ### vnt den kvnech gybechen | da stvnt ovch dieterich ### der recken chvste zwelve | daz eceln wip ### do enpfie si svs mit grvze | vil maniges riteres lip
###### 1353 | ### al di wile vnd ecel | bi chriemhilde stvnt ### do taten do di tvmben | als noch di livte tvnt ### vil manigen pvneiz richen | sah man da geriten ### daz taten cristen helde | vnd ovch di heiden nach ir siten
###### 1354 | ### wi rehte ritterliche | di dieteriches man ### di schefte liezen vliegen | mit trvnzvnen dan ### hohe vber di schilde | gvter ritter hant ### von den tivschen gesten | wart dverchel manich schildes rant
###### 1355 | ### da wart von schefte brechen | vil michel doz vernomen ### do waren von dem lande | di rechen alle chomen ### vnt ovch des chveneges geste | vil manich edel man ### do gie der kvnech riche | mit vrovn criemhilde dan
###### 1356 | ### si sahen bi in stende | ein vil herlich gezelt ### von hvetten was erfvllet | alvmbe daz velt ### da si solden ruwen | nach ir arbeit ### von helden wart gewiset | darvnder manich schoniv meit
###### 1357 | ### mit der chveneginne | da si sit gesaz ### vf rich stvlgewaete | der margrave daz ### hetez wol geschaffen | daz man ez vant vil gvt ### daz gesidele criemhilde | des vroevt sich eceln mvt
###### 1358 | ### waz do redete ecel | daz ist mir vmbechant ### in der sinen zeswen | lag ir wiziv hant ### si gesazen minnechliche | da rvedger der degen ### den kvenech niht wolde lazen | criemhilde heinliche pflegen
###### 1359 | ### do hiez man lan beliben | den bvhvrt veberal ### mit eren wart verendet | da der groze schal ### do giengen zv den hvetten | di eceln man ### man gap in herberge | wil wite allenthalben dan
###### 1360 | ### der tach der het nv ende | si schvf ir gemach ### vnz man den liehten morgen | aber schinen sach ### do was zv den rossen | chomen manich man ### hey waz man chvrzewile | dem chvenege ce eren began
###### 1361 | ### der kvnech ez nach den eren | di hivnen schaffen bat ### do ritten si von tvlne | ce wiene zv der stat ### da fvnden si gezieret | vil maniger vrowen lip ### si enpfiengen wol mit eren | des kvenech eceln wip
###### 1362 | ### mit harte grozem vollen | so was in bereit ### swaz si haben solden | vil manich helt gemeit ### sich vrevte gegen dem schalle | herbergen man began ### des kvneges hohgezite | div hvp sich vrolichen an
###### 1363 | ### si ne mohten niht geherbergen | alle in der stat ### di niht geste waren | rvedger di bat ### daz si herberge | naemen in daz lant ### ich wene man alle zite | bi dem criemhilde vant
###### 1364 | ### den herren dieterichen | vnd andern manigen degen ### si heten sich der rvwe | mit arbeit bewegen ### dvrch daz si den gesten | trosten wol den mvt ### her rvedger vnd sine vrivnde | heten chverzewile gvt
###### 1365 | ### div hohzit was gevallen | an einen pfinxtach ### da der kvnech ecel | bi criemhilde lach ### in der stat ce wiene | si waen so manigen man ### bi ir ersten manne | nie ze dienste gewan
###### 1366 | ### si chvnte sich mit gabe | dem der si nie gesach ### vil maniger darvnder | zv den gesten sprach ### wir wanden daz vrov criemhilt | gvtes niht mohte han ### nv ist hie mit ir gabe | vil manich wunder getan
###### 1367 | ### div hohzit div werte | sibenzehen tage ### ich waene man von deheinem | kvnige mere sage ### des hohzit grozer waere | daz ist vns gar verdeit ### alle di da waren | di trvgen iteniuowe chleit
###### 1368 | ### si waen in niderlande | davor nine gesaz ### mit so manigem recken | dabi so gelovbe ich daz ### was sifrit rich des gvtes | daz er nie gewan ### so manigen recken edele | so si sach vor eceln stan
###### 1369 | ### ovch gap nie deheiner | zv sin selbes hohgezit ### so manigen richen mantel | tief vnd wit ### noch so gvter cleider | der si mohte vil han ### so si dvrch criemhilde | heten alle getan
###### 1370 | ### ir frivnde vnt ovch di geste | di heten einen mvt ### daz si da niht en sparten | deheiner slahte gvt ### swes iemen an si gerte | daz gaben si bereit ### des gestvnt da vil der degene | von milte bloz ane chleit
###### 1371 | ### wi si ce rine saeze | si gedaht ane daz ### bi ir edelen manne | ir ovgen wurden naz ### si hetes vaste haele | deiz iemen chvnde sehen ### ir was nach manigem leide | so vil der eren geschehen
###### 1372 | ### swaz iemen tet mit milte | daz was gar ein wint ### vnz an dieterichen | swaz botelvnges chint ### im gegeben hete | daz was nv gar verswant ### ovch begie da michel wunder | des milten rvedegeres hant
###### 1373 | ### vzer vngerlande | der fverste bloedelin ### der hiez da laere machen | vil manich leitschrin ### von silber vnd von golde | daz wart da hin gegeben ### man gesach des chveneges helde | so rehte vroliche leben
###### 1374 | ### waerbel vnd swemmelin | des kveniges spilman ### ich waene ir ieselicher | zer hohgezit gewan ### wol ce tvsent marchen | oder dannoch baz ### da div schoene criemhilt | bi ecel vnder chrone saz
###### 1375 | ### an dem ahzentem morgen | von wiene si do ritten ### da wart in ritterschepfte | schilde vil versniten ### von spern di da fvrten | di recken an der hant ### svs chom der chvenich ecel | vnz in daz hivnissche lant
###### 1376 | ### ze heimbvrch der alten | si waren vber naht ### do ne chvnde niemen wizzen | wol des volches aht ### mit wi getaner crefte | si ritten veber lant ### hey waz man schoener vrowen | in siner heinmvete vant
###### 1377 | ### ze misenbvrch der richen | da shifften si sich an ### daz wazer wart verdechet | von ross vnd ovch von man ### alsam ez erde waere | swaz man sin vliezen sach ### di wegemveden vrowen | di heten senfte vnd ovch gemach
###### 1378 | ### zesamene was geslozen | manich shif vil gvt ### daz im niht en schadete | di vende noch div flvt ### darveber was gespannen | manich gvt gecelt ### sam ob si noch heten | beiduv lant vnde velt
###### 1379 | ### do chomen disiv maere | ce ecelnpvrch von dan ### do vrevten sich darinne | wip vnde man ### des eceln ingesinde | des e div vrowe pflach ### gelebten sit bi crimhilde | vil manigen vroelichen tach
###### 1380 | ### do stvnden da wartende | vil manich edel meit ### di von helchen tode | heten manigiv leit ### siben chvenige toehter | crimhilt noch da vant ### von den was gezieret | wol allez eceln lant
###### 1381 | ### div ivnchvrowe herrat | noch des gesindes pflach ### div helchen swester tohter | an der vil tvgende lach ### div gemahele dieteriches | eins edeln chvneges chint ### div tohter naentwines | div het vil der eren sint
###### 1382 | ### gegen der geste chvemfte | vrevte sich ir mvt ### ovch was darzv bereitet | vil creftigez gvt ### wer chvnde iv daz bescheiden | wi sit der chvenech saz ### si gelebten da cen hivnen | nie mit der chvneginne baz
###### 1383 | ### do der chvenech mit sinem wibe | von dem stade reit ### wer ieslichiv waere | daz wart do wol geseit ### di edelen criemhilde | si grvztens deste baz ### hey wi gewaltechliche | si sit an helchen stat gesaz
###### 1384 | ### getriwelicher dienste | wart ir vil bechant ### do teilte div chvneginne | golt vnt gewant ### silber vnt gesteine | swaz di des veber rin ### mit ir cen hivnen brahte | daz mvse gar cergeben sin
###### 1385 | ### ovch wurden ir mit dieneste | sider vndertan ### alle des chveniges mage | vnt alle sine man ### daz div vrowe helche | so gewalteclich gebot ### so si nv mvsen dienen | vnz an den criemhilde tot
###### 1386 | ### do stvnt mit soelhen eren | der hof vnt ovch daz lant ### daz man da zallen ziten | di chvrzewile vant ### swar nach ieslichem | daz herce trvch den mvt ### dvrh des chveneges liebe | vnt di kveneginne gvt

<<< Übersicht <<< vorige Seite nächste Seite >>>